@@ -37,3 +37,22 @@ sub scrape {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+WWW::MobileCarrierJP::ThirdForce::UserAgent - get UserAgent informtation from ThirdForce site.
+
+=head1 SYNOPSIS
+
+    use WWW::MobileCarrierJP::ThirdForce::UserAgent;
+    WWW::MobileCarrierJP::ThirdForce::UserAgent->scrape();
+
+=head1 AUTHOR
+
+Tokuhiro Matsuno < tokuhirom gmail com >
+
+=head1 SEE ALSO
+
+L<WWW::MobileCarrierJP>
+
